    		important
    		sanic inspect reload

    		quests

    			tethered
    				sanique = build_sanique ({
    					"tethered": "yes"
    				})
    				sanique ["on"] ()
    				sanique ["off"] ()

    			floating
    				goodest organisms sanique on \
    					--garage-port 40303 \
    					--inspector-port 90302

    				goodest organisms sanique off --inspector-port 90302

    				goodest organisms sanique status --inspector-port 90302

    			restart on code change
    				https://github.com/gorakhargosh/watchdog